# Whistleaio

Asynchronous Python library for Whistle's API using Whistle account email and password.

This package provides an API client for the Whistle API to be used with a Whistle account email and password.
This API is not published, so there is a chance it may break in the future.

## Installation

### PyPI
```
pip3 install whistleaio
```


This package depends on [aiohttp](https://docs.aiohttp.org/en/stable/), and requires `Python 3.7` or greater.
